<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "Ohio";
    var qsoPartyUrl = "http://www.ohqp.org/";
    var overlayUrl = "http://www.no5w.com/OverlayOhioRev4.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Adams", "adam");
  countySelection.options[1] = new Option("Allen", "alle");
  countySelection.options[2] = new Option("Ashland", "ashl");
  countySelection.options[3] = new Option("Ashtabula", "asht");
  countySelection.options[4] = new Option("Athens", "athe");
  countySelection.options[5] = new Option("Auglaize", "augl");
  countySelection.options[6] = new Option("Belmont", "belm");
  countySelection.options[7] = new Option("Brown", "brow");
  countySelection.options[8] = new Option("Butler", "butl");
  countySelection.options[9] = new Option("Carroll", "carr");
  countySelection.options[10] = new Option("Champaign", "cham");
  countySelection.options[11] = new Option("Clark", "clar");
  countySelection.options[12] = new Option("Clermont", "cler");
  countySelection.options[13] = new Option("Clinton", "clin");
  countySelection.options[14] = new Option("Columbiana", "colu");
  countySelection.options[15] = new Option("Coshocton", "cosh");
  countySelection.options[16] = new Option("Crawford", "craw");
  countySelection.options[17] = new Option("Cuyahoga", "cuya");
  countySelection.options[18] = new Option("Darke", "dark");
  countySelection.options[19] = new Option("Defiance", "defi");
  countySelection.options[20] = new Option("Delaware", "dela");
  countySelection.options[21] = new Option("Erie", "erie");
  countySelection.options[22] = new Option("Fairfield", "fair");
  countySelection.options[23] = new Option("Fayette", "faye");
  countySelection.options[24] = new Option("Franklin", "fran");
  countySelection.options[25] = new Option("Fulton", "fult");
  countySelection.options[26] = new Option("Gallia", "gall");
  countySelection.options[27] = new Option("Geauga", "geau");
  countySelection.options[28] = new Option("Greene", "gree");
  countySelection.options[29] = new Option("Guernsey", "guer");
  countySelection.options[30] = new Option("Hamilton", "hami");
  countySelection.options[31] = new Option("Hancock", "hanc");
  countySelection.options[32] = new Option("Hardin", "hard");
  countySelection.options[33] = new Option("Harrison", "harr");
  countySelection.options[34] = new Option("Henry", "henr");
  countySelection.options[35] = new Option("Highland", "high");
  countySelection.options[36] = new Option("Hocking", "hock");
  countySelection.options[37] = new Option("Holmes", "holm");
  countySelection.options[38] = new Option("Huron", "huro");
  countySelection.options[39] = new Option("Jackson", "jack");
  countySelection.options[40] = new Option("Jefferson", "jeff");
  countySelection.options[41] = new Option("Knox", "knox");
  countySelection.options[42] = new Option("Lake", "lake");
  countySelection.options[43] = new Option("Lawrence", "lawr");
  countySelection.options[44] = new Option("Licking", "lick");
  countySelection.options[45] = new Option("Logan", "loga");
  countySelection.options[46] = new Option("Lorain", "lora");
  countySelection.options[47] = new Option("Lucas", "luca");
  countySelection.options[48] = new Option("Madison", "madi");
  countySelection.options[49] = new Option("Mahoning", "maho");
  countySelection.options[50] = new Option("Marion", "mari");
  countySelection.options[51] = new Option("Medina", "medi");
  countySelection.options[52] = new Option("Meigs", "meig");
  countySelection.options[53] = new Option("Mercer", "merc");
  countySelection.options[54] = new Option("Miami", "miam");
  countySelection.options[55] = new Option("Monroe", "monr");
  countySelection.options[56] = new Option("Montgomery", "mont");
  countySelection.options[57] = new Option("Morgan", "morg");
  countySelection.options[58] = new Option("Morrow", "morr");
  countySelection.options[59] = new Option("Muskingum", "musk");
  countySelection.options[60] = new Option("Noble", "nobl");
  countySelection.options[61] = new Option("Ottawa", "otta");
  countySelection.options[62] = new Option("Paulding", "paul");
  countySelection.options[63] = new Option("Perry", "perr");
  countySelection.options[64] = new Option("Pickaway", "pick");
  countySelection.options[65] = new Option("Pike", "pike");
  countySelection.options[66] = new Option("Portage", "port");
  countySelection.options[67] = new Option("Preble", "preb");
  countySelection.options[68] = new Option("Putnam", "putn");
  countySelection.options[69] = new Option("Richland", "rich");
  countySelection.options[70] = new Option("Ross", "ross");
  countySelection.options[71] = new Option("Sandusky", "sand");
  countySelection.options[72] = new Option("Scioto", "scio");
  countySelection.options[73] = new Option("Seneca", "sene");
  countySelection.options[74] = new Option("Shelby", "shel");
  countySelection.options[75] = new Option("Stark", "star");
  countySelection.options[76] = new Option("Summit", "summ");
  countySelection.options[77] = new Option("Trumbull", "trum");
  countySelection.options[78] = new Option("Tuscarawas", "tusc");
  countySelection.options[79] = new Option("Union", "unio");
  countySelection.options[80] = new Option("VanWert", "vanw");
  countySelection.options[81] = new Option("Vinton", "vint");
  countySelection.options[82] = new Option("Warren", "warr");
  countySelection.options[83] = new Option("Washington", "wash");
  countySelection.options[84] = new Option("Wayne", "wayn");
  countySelection.options[85] = new Option("Williams", "will");
  countySelection.options[86] = new Option("Wood", "wood");
  countySelection.options[87] = new Option("Wyandot", "wyan");
  addMarker(38.82590000, -83.48650000, "Adams", "adam");
  addMarker(40.78180000, -84.13860000, "Allen", "alle");
  addMarker(40.81040000, -82.28090000, "Ashland", "ashl");
  addMarker(41.73840000, -80.76190000, "Ashtabula", "asht");
  addMarker(39.36820000, -82.01010000, "Athens", "athe");
  addMarker(40.52030000, -84.16800000, "Auglaize", "augl");
  addMarker(40.01130000, -80.97010000, "Belmont", "belm");
  addMarker(38.94700000, -83.86290000, "Brown", "brow");
  addMarker(39.44090000, -84.57580000, "Butler", "butl");
  addMarker(40.57690000, -81.09120000, "Carroll", "carr");
  addMarker(40.14230000, -83.76520000, "Champaign", "cham");
  addMarker(39.90440000, -83.78090000, "Clark", "clar");
  addMarker(39.02050000, -84.15640000, "Clermont", "cler");
  addMarker(39.39600000, -83.79150000, "Clinton", "clin");
  addMarker(40.75630000, -80.80310000, "Columbiana", "colu");
  addMarker(40.30360000, -81.90600000, "Coshocton", "cosh");
  addMarker(40.85000000, -82.91850000, "Crawford", "craw");
  addMarker(41.45260000, -81.67280000, "Cuyahoga", "cuya");
  addMarker(40.13550000, -84.61910000, "Darke", "dark");
  addMarker(41.29670000, -84.51570000, "Defiance", "defi");
  addMarker(40.28490000, -82.99730000, "Delaware", "dela");
  addMarker(41.45160000, -82.64780000, "Erie", "erie");
  addMarker(39.74780000, -82.60460000, "Fairfield", "fair");
  addMarker(39.54710000, -83.46130000, "Fayette", "faye");
  addMarker(39.96900000, -83.01140000, "Franklin", "fran");
  addMarker(41.60280000, -84.13850000, "Fulton", "fult");
  addMarker(38.80900000, -82.33910000, "Gallia", "gall");
  addMarker(41.53100000, -81.19670000, "Geauga", "geau");
  addMarker(39.70040000, -83.88030000, "Greene", "gree");
  addMarker(40.03080000, -81.47730000, "Guernsey", "guer");
  addMarker(39.16690000, -84.53820000, "Hamilton", "hami");
  addMarker(40.99330000, -83.65070000, "Hancock", "hanc");
  addMarker(40.66190000, -83.64780000, "Hardin", "hard");
  addMarker(40.29650000, -81.10250000, "Harrison", "harr");
  addMarker(41.32670000, -84.11170000, "Henry", "henr");
  addMarker(39.19880000, -83.60790000, "Highland", "high");
  addMarker(39.51160000, -82.45390000, "Hocking", "hock");
  addMarker(40.55620000, -81.93530000, "Holmes", "holm");
  addMarker(41.14160000, -82.58890000, "Huron", "huro");
  addMarker(39.02620000, -82.61590000, "Jackson", "jack");
  addMarker(40.37730000, -80.76820000, "Jefferson", "jeff");
  addMarker(40.40610000, -82.46580000, "Knox", "knox");
  addMarker(41.71230000, -81.24600000, "Lake", "lake");
  addMarker(38.62610000, -82.55150000, "Lawrence", "lawr");
  addMarker(40.09510000, -82.48270000, "Licking", "lick");
  addMarker(40.38400000, -83.76730000, "Logan", "loga");
  addMarker(41.28960000, -82.11250000, "Lorain", "lora");
  addMarker(41.57340000, -83.52450000, "Lucas", "luca");
  addMarker(39.90340000, -83.42980000, "Madison", "madi");
  addMarker(41.01700000, -80.80290000, "Mahoning", "maho");
  addMarker(40.56940000, -83.13930000, "Marion", "mari");
  addMarker(41.13270000, -81.92920000, "Medina", "medi");
  addMarker(39.03970000, -82.03300000, "Meigs", "meig");
  addMarker(40.54000000, -84.61950000, "Mercer", "merc");
  addMarker(40.04000000, -84.22980000, "Miami", "miam");
  addMarker(39.70480000, -81.07020000, "Monroe", "monr");
  addMarker(39.75040000, -84.26860000, "Montgomery", "mont");
  addMarker(39.61010000, -81.83320000, "Morgan", "morg");
  addMarker(40.52880000, -82.82290000, "Morrow", "morr");
  addMarker(39.96120000, -81.96250000, "Muskingum", "musk");
  addMarker(39.76850000, -81.46580000, "Noble", "nobl");
  addMarker(41.59080000, -83.05510000, "Ottawa", "otta");
  addMarker(41.12140000, -84.57260000, "Paulding", "paul");
  addMarker(39.74030000, -82.24840000, "Perry", "perr");
  addMarker(39.64070000, -82.99920000, "Pickaway", "pick");
  addMarker(39.07280000, -83.08580000, "Pike", "pike");
  addMarker(41.16820000, -81.19660000, "Portage", "port");
  addMarker(39.74260000, -84.64700000, "Preble", "preb");
  addMarker(41.01340000, -84.13990000, "Putnam", "putn");
  addMarker(40.77290000, -82.53210000, "Richland", "rich");
  addMarker(39.34200000, -83.06730000, "Ross", "ross");
  addMarker(41.37710000, -83.12990000, "Sandusky", "sand");
  addMarker(38.79330000, -82.96050000, "Scioto", "scio");
  addMarker(41.12440000, -83.12540000, "Seneca", "sene");
  addMarker(40.33360000, -84.21830000, "Shelby", "shel");
  addMarker(40.81180000, -81.36830000, "Stark", "star");
  addMarker(41.12880000, -81.54000000, "Summit", "summ");
  addMarker(41.31750000, -80.76130000, "Trumbull", "trum");
  addMarker(40.44040000, -81.48850000, "Tuscarawas", "tusc");
  addMarker(40.30690000, -83.36060000, "Union", "unio");
  addMarker(40.83760000, -84.57170000, "VanWert", "vanw");
  addMarker(39.21170000, -82.51150000, "Vinton", "vint");
  addMarker(39.42250000, -84.17110000, "Warren", "warr");
  addMarker(39.43090000, -81.44510000, "Washington", "wash");
  addMarker(40.82940000, -81.88850000, "Wayne", "wayn");
  addMarker(41.56590000, -84.57410000, "Williams", "will");
  addMarker(41.39230000, -83.64900000, "Wood", "wood");
  addMarker(40.84020000, -83.31360000, "Wyandot", "wyan");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

